@@ -1,4 +1,4 @@
-t1way <- function(formula, data, tr = 0.2) {
+t1way <- function(formula, data, tr = 0.2, alpha = 0.05, nboot = 100) {
 
   if (missing(data)) {
     mf <- model.frame(formula)
@@ -41,30 +41,40 @@ t1way <- function(formula, data, tr = 0.2) {
  nu2 <- 1./(3*sum((1-w/u)^2/(h-1))/(J^2-1))
  sig <- 1-pf(TEST,nu1,nu2)
  
- 
- 
+ ## effect size
  chkn=var(nv)
- if(chkn==0){
+ if(chkn==0){                       ## equal sample size
    top=var(xbar)
    bot=winvarN(pts,tr=tr)
-   e.pow=top/bot
- }
- if(chkn!=0){
-   vals=0
-   N=min(nv)
-   xdat=list()
-   nboot = 100
-   for(i in 1:nboot){
-     for(j in 1:J){
-       xdat[[j]]=sample(x[[j]],N)
-     }
-     vals[i]=t1way.effect(xdat,tr=tr)$Var.Explained
-   }
-   loc.fun=median
-   e.pow=loc.fun(vals,na.rm=TRUE)
+   e.pow = sqrt(top/bot)            ## exact computation
  }
  
- result <- list(test = TEST, df1 =nu1, df2 = nu2, p.value = sig, effsize = sqrt(e.pow), call = cl)
+## unequal sample size and bootstrap CI
+ vals=0
+ N=min(nv)
+ xdat=list()
+ for(i in 1:nboot){
+   for(j in 1:J){
+     xdat[[j]] <- sample(x[[j]], N, replace = TRUE)
+   }
+   #vals[i]=t1way.effect(xdat,tr=tr)$Var.Explained
+   vals[i] <- t1wayv2(xdat, tr = tr, nboot = 5, SEED = FALSE)$Effect.Size
+ }
+ loc.fun <- median
+ if(chkn!=0) e.pow <- loc.fun(vals,na.rm=TRUE)    ## unequal sample size effect size (bootstrap)
+
+## CI computation   
+ ilow <- round((alpha/2) * nboot)
+ ihi <- nboot - ilow
+ ilow <- ilow+1
+ val <- sort(vals)
+ ci <- val[ilow]
+ ci[2] <- val[ihi]
+   #if(chk$p.value>alpha)ci[1]=0
+
+ 
+ result <- list(test = TEST, df1 =nu1, df2 = nu2, p.value = sig, effsize = e.pow, effsize_ci = ci, 
+                call = cl)
  class(result) <- c("t1way")
  result
 }
