@@ -74,7 +74,8 @@ t2way <- function(formula, data, tr = 0.2){
   }
   AB.p.value=irem/1000
   tmeans=matrix(tmeans,J,K,byrow=T)
-  result <- list(Qa=Qa$teststat, A.p.value=A.p.value, Qb=Qb$teststat, B.p.value=B.p.value, Qab=Qab$teststat, AB.p.value=AB.p.value, call = cl, varnames = colnames(mf))
+  result <- list(Qa=Qa$teststat, A.p.value=A.p.value, Qb=Qb$teststat, B.p.value=B.p.value, Qab=Qab$teststat, 
+                 AB.p.value=AB.p.value, call = cl, varnames = colnames(mf), dim = c(J,K))
   class(result) <- c("t2way")
   result
 }
